/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.internal.lazy;

import javax.annotation.concurrent.NotThreadSafe;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.function.Supplier;

@NotThreadSafe
class UnsafeLazy<T> implements Lazy<T> {
    private Supplier<T> supplier;
    private T value;

    public UnsafeLazy(Supplier<T> supplier) {
        this.supplier = supplier;
    }

    @Override
    public T get() {
        return ensureValue();
    }

    private T ensureValue() {
        if (supplier != null) {
            value = supplier.get();
            supplier = null;
        }
        return value;
    }

    @Override
    public void use(Consumer<? super T> consumer) {
        consumer.accept(ensureValue());
    }

    @Override
    public <V> V apply(Function<? super T, V> function) {
        return function.apply(ensureValue());
    }

}
